{
    "$graph": [
        {
            "class": "Workflow",
            "label": "FragPipe: TMT Integrator and QC",
            "doc": "This workflow step executes TMT-Integrator using the report tables generated by Philosopher. The program applies a series of statistical filters, and high-quality thresholds to filter the data. Summary report tables are created containing peptides, proteins, genes, and phosphosites (only for phospho-enriched data sets).",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/psm_file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "https://sevenbridges.comfileTypes": "TSV",
                    "https://sevenbridges.comx": -348.1875,
                    "https://sevenbridges.comy": -238.8984375
                },
                {
                    "id": "#main/database",
                    "type": "File",
                    "https://sevenbridges.comfileTypes": "FAS",
                    "https://sevenbridges.comx": -373.1875,
                    "https://sevenbridges.comy": -3.898444652557373
                }
            ],
            "steps": [
                {
                    "id": "#main/tmt_integrator_qc",
                    "label": "TMT-Integrator QC",
                    "in": [
                        {
                            "id": "#main/tmt_integrator_qc/tmt_gene_report",
                            "source": "#main/tmt_integrator/abundance_by_gene_report"
                        }
                    ],
                    "run": "#tmt_integrator_qc.cwl",
                    "out": [
                        {
                            "id": "#main/tmt_integrator_qc/tmt_qc_report"
                        }
                    ],
                    "https://sevenbridges.comx": 49,
                    "https://sevenbridges.comy": 12
                },
                {
                    "id": "#main/tmt_integrator",
                    "label": "tmt_integrator",
                    "in": [
                        {
                            "id": "#main/tmt_integrator/psm_file",
                            "source": [
                                "#main/psm_file"
                            ]
                        },
                        {
                            "id": "#main/tmt_integrator/database",
                            "source": "#main/database"
                        }
                    ],
                    "run": "#tmt_integrator.cwl",
                    "out": [
                        {
                            "id": "#main/tmt_integrator/all_report_files"
                        },
                        {
                            "id": "#main/tmt_integrator/abundance_by_gene_report"
                        }
                    ],
                    "https://sevenbridges.comx": -118,
                    "https://sevenbridges.comy": -138
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comAWSInstanceType",
                    "value": "r5.xlarge;ebs-gp2;200"
                }
            ],
            "id": "#main",
            "https://sevenbridges.comappVersion": [
                "v1.1"
            ],
            "https://sevenbridges.comcategories": [
                "Proteomics"
            ],
            "https://sevenbridges.comcontent_hash": "ae0e5b97dd4fa1b912e0df5f4dc491c2e6c808735c5e97296e8d15f920a6d8e8f",
            "https://sevenbridges.comcontributors": [
                "david.roberson"
            ],
            "https://sevenbridges.comcreatedBy": "david.roberson",
            "https://sevenbridges.comcreatedOn": 1618978230,
            "https://sevenbridges.comid": "david.roberson/build-fragpipe-proteomics-pipeline-tutorial/fragpipe-tmt-integrator-and-qc/0",
            "https://sevenbridges.comimage_url": "https://cgc.sbgenomics.com/ns/brood/images/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/fragpipe-tmt-integrator-and-qc/0.png",
            "https://sevenbridges.comlatestRevision": 0,
            "https://sevenbridges.comlinks": [
                {
                    "id": "#",
                    "label": "fragpipe.nesvilab.org"
                }
            ],
            "https://sevenbridges.commodifiedBy": "david.roberson",
            "https://sevenbridges.commodifiedOn": 1618978230,
            "https://sevenbridges.comoriginal_source": "https://cgc-api.sbgenomics.com/v2/apps/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/fragpipe-tmt-integrator-and-qc/0/raw/",
            "https://sevenbridges.comproject": "david.roberson/build-fragpipe-proteomics-pipeline-tutorial",
            "https://sevenbridges.comprojectName": "BUILD: FragPipe Proteomics Pipeline Tutorial",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 0,
            "https://sevenbridges.comrevisionNotes": "Uploaded using sbpack v2020.10.05. \nSource: \nrepo: https://github.com/davidroberson/fragpipe-proteomics-pipeline-tutorial.git\nfile: \ncommit: (uncommitted file)",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618978230,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": "Uploaded using sbpack v2020.10.05. \nSource: \nrepo: https://github.com/davidroberson/fragpipe-proteomics-pipeline-tutorial.git\nfile: \ncommit: (uncommitted file)"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comtoolAuthor": "Felipe da Veiga Leprevost",
            "https://sevenbridges.comtoolkit": "FragPipe",
            "https://sevenbridges.comtoolkitVersion": "v15.0",
            "https://sevenbridges.comvalidationErrors": [],
            "https://sevenbridges.comwrapperAuthor": "Felipe da Veiga Leprevost; Dave Roberson",
            "outputs": [
                {
                    "id": "#main/all_report_files",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": [
                        "#main/tmt_integrator/all_report_files"
                    ],
                    "https://sevenbridges.comx": 58.26561737060547,
                    "https://sevenbridges.comy": -267.1984558105469
                },
                {
                    "id": "#main/tmt_qc_report",
                    "label": "TMT QC Report",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": [
                        "#main/tmt_integrator_qc/tmt_qc_report"
                    ],
                    "https://sevenbridges.comx": 207.99998474121094,
                    "https://sevenbridges.comy": -156.19845581054688
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "tmt_integrator",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 30000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "cgc-images.sbgenomics.com/david.roberson/tmt-integrator:2.4.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "tmt-i.yml",
                            "writable": false,
                            "entry": "tmtintegrator:\n  memory: 30                                      # memory allocation, in Gb\n  protein_database: 2020-03-30-decoys-reviewed-contam-UP000005640.fas                            # protein fasta file\n  output: ./                         # the location of output files\n  channel_num: 10                                 # number of channels in the multiplex (e.g. 10, 11)\n  ref_tag: pool                                  # unique tag for identifying the reference channel (Bridge sample added to each multiplex)\n  groupby: -1                                     # level of data summarization(0: PSM aggregation to the gene level; 1: protein; 2: peptide sequence; 3: multiple PTM sites; 4: single PTM site; -1: generate reports at all levels)\n  psm_norm: false                                 # perform additional retention time-based normalization at the PSM level\n  outlier_removal: true                           # perform outlier removal\n  prot_norm:  1                                   # normalization (0: None; 1: MD (median centering); 2: GN (median centering + variance scaling); -1: generate reports with all normalization options)\n  min_pep_prob: 0.9                               # minimum PSM probability threshold (in addition to FDR-based filtering by Philosopher)\n  min_purity: 0.5                                 # ion purity score threshold\n  min_percent: 0.05                               # remove low intensity PSMs (e.g. value of 0.05 indicates removal of PSMs with the summed TMT reporter ions intensity in the lowest 5% of all PSMs)\n  unique_pep: false                               # allow PSMs with unique peptides only (if true) or unique plus razor peptides (if false), as classified by Philosopher and defined in PSM.tsv files\n  unique_gene: 0                                  # additional, gene-level uniqueness filter (0: allow all PSMs; 1: remove PSMs mapping to more than one GENE with evidence of expression in the dataset; 2:remove all PSMs mapping to more than one GENE in the fasta file)\n  best_psm: true                                  # keep the best PSM only (highest summed TMT intensity) among all redundant PSMs within the same LC-MS run\n  prot_exclude: none                              # exclude proteins with specified tags at the beginning of the accession number (e.g. none: no exclusion; sp|,tr| : exclude protein with sp| or tr|)\n  allow_overlabel: true                           # allow PSMs with TMT on S (when overlabeling on S was allowed in the database search)\n  allow_unlabeled: false                          # allow PSMs without TMT tag or acetylation on the peptide n-terminus \n  mod_tag: none                                   # PTM info for generation of PTM-specific reports (none: for Global data; S[167],T[181],Y[243]: for Phospho; K[170]: for K-Acetyl)\n  min_site_prob: -1                               # site localization confidence threshold (-1: for Global; 0: as determined by the search engine; above 0 (e.g. 0.75): PTMProphet probability, to be used with phosphorylation only)\n  ms1_int: true                                   # use MS1 precursor ion intensity (if true) or MS2 reference intensity (if false) as part of the reference sample abundance estimation \n  top3_pep: true                                  # use top 3 most intense peptide ions as part of the reference sample abundance estimation\n  print_RefInt: false                             # print individual reference sample abundance estimates for each multiplex in the final reports (in addition to the combined reference sample abundance estimate)\n  add_Ref: -1                                     # add an artificial reference channel if there is no reference channel or export raw abundance (-1: don't add the reference; 0: use summation as the reference; 1: use average as the reference; 2: use median as the reference; 3: export raw abundance)\n  max_pep_prob_thres: 0                           # the threshold for maximum peptide probability\n  min_ntt: 0                                      # minimum allowed number of enzymatic termini\n"
                        },
                        "$(inputs.database)",
                        {
                            "entryname": "rename_reports.sh",
                            "writable": false,
                            "entry": "for file in *.tsv; do mv \"$file\" `echo $file | tr '=' '_'` ; done\n"
                        },
                        {
                            "entryname": "Dockerfile",
                            "writable": false,
                            "entry": "FROM ubuntu:18.04\n\n# MAINTAINER Felipe da Veiga Leprevost <felipevl@umich.edu>\n\n# Set noninterative mode\nENV DEBIAN_FRONTEND noninteractive\n\n# apt update and install global requirements\nRUN apt-get clean all &&  \\\n    apt-get update &&     \\\n    apt-get upgrade -y && \\\n    apt-get install -y    \\\n    openjdk-8-jre\n\n\n# create shared folders\nRUN mkdir /data\n\n# Add $HOME/bin to path\nENV PATH=$PATH:/data\n\n# Share default volumes\nVOLUME [\"/data\", \"/config\"]\n\n# Overwrite this with 'CMD []' in a dependent Dockerfile\nCMD [\"/bin/bash\"]\n\n# change workdir\nWORKDIR /data\n\nADD https://github.com/Nesvilab/TMT-Integrator/releases/download/2.4.0/TMTIntegrator_v2.4.0.jar /data\nADD https://github.com/Nesvilab/TMT-Integrator/releases/download/2.4.0/tmt-i_param_v2.4.0.yml /data\n\nENV PATH /data/:$PATH\n"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file)) {\n        file['metadata'] = {}\n    }\n    for (var key in metadata) {\n        file['metadata'][key] = metadata[key];\n    }\n    return file\n};\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!o2) {\n        return o1;\n    };\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n        for (var key in commonMetadata) {\n            if (!(key in example)) {\n                delete commonMetadata[key]\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n        if (o1.secondaryFiles) {\n            o1.secondaryFiles = inheritMetadata(o1.secondaryFiles, o2)\n        }\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n            if (o1[i].secondaryFiles) {\n                o1[i].secondaryFiles = inheritMetadata(o1[i].secondaryFiles, o2)\n            }\n        }\n    }\n    return o1;\n};"
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#tmt_integrator.cwl/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/tmt_integrator/1/psm_file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 0,
                        "shellQuote": false
                    },
                    "https://sevenbridges.comfileTypes": "TSV"
                },
                {
                    "id": "#tmt_integrator.cwl/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/tmt_integrator/1/database",
                    "type": "File",
                    "https://sevenbridges.comfileTypes": "FAS"
                }
            ],
            "outputs": [
                {
                    "id": "#tmt_integrator.cwl/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/tmt_integrator/1/all_report_files",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*tsv",
                        "outputEval": "$(inheritMetadata(self, inputs.psm_file))"
                    }
                },
                {
                    "id": "#tmt_integrator.cwl/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/tmt_integrator/1/abundance_by_gene_report",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Report_abundance_groupby_gene_protNorm_MD_gu_0.tsv"
                    }
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx30G",
                "-jar",
                "/data/TMTIntegrator_v2.4.0.jar",
                "tmt-i.yml"
            ],
            "arguments": [
                {
                    "prefix": "",
                    "position": 99,
                    "valueFrom": "&& bash rename_reports.sh",
                    "shellQuote": false
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comSaveLogs",
                    "value": "*.yml"
                }
            ],
            "id": "#tmt_integrator.cwl",
            "https://sevenbridges.comappVersion": [
                "v1.1"
            ],
            "https://sevenbridges.comcontent_hash": "a48c0d8277d6ea77fc88d98f7a34ca77d55a137702303d0e525603d18fa192f57",
            "https://sevenbridges.comcontributors": [
                "david.roberson"
            ],
            "https://sevenbridges.comcreatedBy": "david.roberson",
            "https://sevenbridges.comcreatedOn": 1618936765,
            "https://sevenbridges.comid": "david.roberson/build-fragpipe-proteomics-pipeline-tutorial/tmt_integrator/1",
            "https://sevenbridges.comimage_url": null,
            "https://sevenbridges.comlatestRevision": 1,
            "https://sevenbridges.commodifiedBy": "david.roberson",
            "https://sevenbridges.commodifiedOn": 1618936850,
            "https://sevenbridges.comproject": "david.roberson/build-fragpipe-proteomics-pipeline-tutorial",
            "https://sevenbridges.comprojectName": "BUILD: FragPipe Proteomics Pipeline Tutorial",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 1,
            "https://sevenbridges.comrevisionNotes": "added dockerfile",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618936765,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": "Uploaded using sbpack v2020.10.05. \nSource: \nrepo: https://github.com/davidroberson/fragpipe-proteomics-pipeline-tutorial.git\nfile: \ncommit: (uncommitted file)"
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618936850,
                    "https://sevenbridges.comrevision": 1,
                    "https://sevenbridges.comrevisionNotes": "added dockerfile"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comtoolkit": "FragPipe",
            "https://sevenbridges.comvalidationErrors": []
        },
        {
            "class": "CommandLineTool",
            "label": "TMT-Integrator QC",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "rocker/verse:4.0.4"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "gene_report.Rmd",
                            "writable": false,
                            "entry": "---\ntitle: \"TMT-Integrator Quality Control\"\ndate: \"`r Sys.Date()`\"\noutput:\n  html_document: default\neditor_options: \n  chunk_output_type: console\n---\n\n```{r setup, include=FALSE}\nlibrary(tidyverse)\nlibrary(RColorBrewer)\n```\n\n```{r, include=FALSE}\nsource(\"input.R\")\n\nwide_data = read_tsv(file = gene_report_path) %>% # load the TMT-Integrator gene report\n  drop_na() %>%   # remove rows containing NAs and pivot \n  glimpse()\n  \nlong_data = wide_data %>%   \n  pivot_longer(-names(.)[1:5], names_to = \"variable\", values_to=\"value\") %>% \n  group_by(variable) %>% #create variable group num\n  mutate(variable_num = cur_group_id()) %>% \n  ungroup() %>% \n  select(variable_num, everything()) %>% \n  glimpse()\n\n```\n\n\n```{r message = FALSE, fig.height = 8, fig.width = 12, echo=FALSE}\nlong_data %>%\n  filter(variable_num %in% c(1:20)) %>% #filter for first 20 channels\nggplot(aes(x = variable, y = value)) +\n  geom_boxplot(outlier.colour = NA, alpha = 0.2, fill = \"lightcyan\") +\n  stat_boxplot(geom = 'errorbar', linetype = 1, width = 0.1) +\n  labs(title = \"Protein Intensities variance and distribution\") +\n  theme(text = \n        element_text(size = 9),\n        axis.text.x = element_text(size = 9, angle = 45, hjust = 1),\n        axis.title.x = element_blank(),\n        axis.title.y = element_blank(),\n        panel.border = element_rect(colour = \"black\", fill = NA, size = 1))\n\n```\n\n\n```{r message=FALSE, echo=FALSE, fig.heigh = 8, fig.width = 14}\n\nlong_data %>% \n  #filter(variable_num %in% c(1:10)) %>% #filter for first 10 channels\n  ggplot() +\n  geom_density(aes(x = value, color = variable)) +\n  labs(title = \"Protein Intensities variance and distribution\", color = \"samples\") +\n  theme(text = element_text(size = 9),\n        axis.text = element_text(size = 9),\n        axis.title.x = element_blank(),\n        axis.title.y = element_blank(),\n        legend.position = \"none\",\n        panel.border = element_rect(colour = \"black\", fill = NA, size = 1))\n```\n\n```{r, message=FALSE, echo=FALSE, fig.height = 16, fig.width = 12}\n\n\nwide_data %>% \n  select(6:ncol(.)) %>% \n  as.matrix() %>% \nheatmap(Rowv = NA, col = colorRampPalette(brewer.pal(8, \"Blues\"))(25), margins = c(16,10))\n```\n\n\n\n\n\n\n\n\n"
                        },
                        {
                            "entryname": "input.R",
                            "writable": false,
                            "entry": "gene_report_path = \"$(inputs.tmt_gene_report.path)\""
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nvar setMetadata = function(file, metadata) {\n    if (!('metadata' in file)) {\n        file['metadata'] = {}\n    }\n    for (var key in metadata) {\n        file['metadata'][key] = metadata[key];\n    }\n    return file\n};\nvar inheritMetadata = function(o1, o2) {\n    var commonMetadata = {};\n    if (!o2) {\n        return o1;\n    };\n    if (!Array.isArray(o2)) {\n        o2 = [o2]\n    }\n    for (var i = 0; i < o2.length; i++) {\n        var example = o2[i]['metadata'];\n        for (var key in example) {\n            if (i == 0)\n                commonMetadata[key] = example[key];\n            else {\n                if (!(commonMetadata[key] == example[key])) {\n                    delete commonMetadata[key]\n                }\n            }\n        }\n        for (var key in commonMetadata) {\n            if (!(key in example)) {\n                delete commonMetadata[key]\n            }\n        }\n    }\n    if (!Array.isArray(o1)) {\n        o1 = setMetadata(o1, commonMetadata)\n        if (o1.secondaryFiles) {\n            o1.secondaryFiles = inheritMetadata(o1.secondaryFiles, o2)\n        }\n    } else {\n        for (var i = 0; i < o1.length; i++) {\n            o1[i] = setMetadata(o1[i], commonMetadata)\n            if (o1[i].secondaryFiles) {\n                o1[i].secondaryFiles = inheritMetadata(o1[i].secondaryFiles, o2)\n            }\n        }\n    }\n    return o1;\n};"
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#tmt_integrator_qc.cwl/david.roberson/pdc-webinar-devl-2/tmt-integrator-qc/8/tmt_gene_report",
                    "type": "File"
                }
            ],
            "outputs": [
                {
                    "id": "#tmt_integrator_qc.cwl/david.roberson/pdc-webinar-devl-2/tmt-integrator-qc/8/tmt_qc_report",
                    "label": "TMT QC Report",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.html",
                        "outputEval": "$(inheritMetadata(self, inputs.tmt_gene_report))"
                    }
                }
            ],
            "stdout": "markdown.log",
            "baseCommand": [
                "Rscript",
                "-e",
                "'require(rmarkdown);",
                "render(\"gene_report.Rmd\")'"
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comSaveLogs",
                    "value": "*.R"
                },
                {
                    "class": "https://sevenbridges.comSaveLogs",
                    "value": "*.log"
                }
            ],
            "id": "#tmt_integrator_qc.cwl",
            "https://sevenbridges.comappVersion": [
                "v1.1"
            ],
            "https://sevenbridges.comcontent_hash": "a812f4daebbb5c2ea3e209dc9ffcbffec95187a0060b6d3c51f2d40c0d4d942fe",
            "https://sevenbridges.comcontributors": [
                "david.roberson"
            ],
            "https://sevenbridges.comcreatedBy": "david.roberson",
            "https://sevenbridges.comcreatedOn": 1618447418,
            "https://sevenbridges.comid": "david.roberson/pdc-webinar-devl-2/tmt-integrator-qc/8",
            "https://sevenbridges.comimage_url": null,
            "https://sevenbridges.comlatestRevision": 8,
            "https://sevenbridges.commodifiedBy": "david.roberson",
            "https://sevenbridges.commodifiedOn": 1618501572,
            "https://sevenbridges.comproject": "david.roberson/pdc-webinar-devl-2",
            "https://sevenbridges.comprojectName": "PDC Webinar Devl 2",
            "https://sevenbridges.compublisher": "sbg",
            "https://sevenbridges.comrevision": 8,
            "https://sevenbridges.comrevisionNotes": "removed glimpse",
            "https://sevenbridges.comrevisionsInfo": [
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618447418,
                    "https://sevenbridges.comrevision": 0,
                    "https://sevenbridges.comrevisionNotes": null
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618487828,
                    "https://sevenbridges.comrevision": 1,
                    "https://sevenbridges.comrevisionNotes": "added report"
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618487853,
                    "https://sevenbridges.comrevision": 2,
                    "https://sevenbridges.comrevisionNotes": ""
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618488399,
                    "https://sevenbridges.comrevision": 3,
                    "https://sevenbridges.comrevisionNotes": ""
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618494102,
                    "https://sevenbridges.comrevision": 4,
                    "https://sevenbridges.comrevisionNotes": ""
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618496433,
                    "https://sevenbridges.comrevision": 5,
                    "https://sevenbridges.comrevisionNotes": ""
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618499775,
                    "https://sevenbridges.comrevision": 6,
                    "https://sevenbridges.comrevisionNotes": ""
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618500945,
                    "https://sevenbridges.comrevision": 7,
                    "https://sevenbridges.comrevisionNotes": "added parenthesis"
                },
                {
                    "https://sevenbridges.commodifiedBy": "david.roberson",
                    "https://sevenbridges.commodifiedOn": 1618501572,
                    "https://sevenbridges.comrevision": 8,
                    "https://sevenbridges.comrevisionNotes": "removed glimpse"
                }
            ],
            "https://sevenbridges.comsbgMaintained": false,
            "https://sevenbridges.comvalidationErrors": []
        }
    ],
    "cwlVersion": "v1.1",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
