cwlVersion: v1.1
class: Workflow
label: 'FragPipe: TMT Integrator and QC'
doc: |-
  This workflow step executes TMT-Integrator using the report tables generated by Philosopher. The program applies a series of statistical filters, and high-quality thresholds to filter the data. Summary report tables are created containing peptides, proteins, genes, and phosphosites (only for phospho-enriched data sets).
$namespaces:
  sbg: https://sevenbridges.com

requirements:
- class: InlineJavascriptRequirement
- class: StepInputExpressionRequirement
- class: SubworkflowFeatureRequirement

inputs:
- id: psm_file
  type:
    type: array
    items: File
  sbg:fileTypes: TSV
  sbg:x: -348.1875
  sbg:y: -238.8984375
- id: database
  type: File
  sbg:fileTypes: FAS
  sbg:x: -373.1875
  sbg:y: -3.898444652557373

outputs:
- id: all_report_files
  type:
  - 'null'
  - type: array
    items: File
  outputSource:
  - tmt_integrator/all_report_files
  sbg:x: 58.26561737060547
  sbg:y: -267.1984558105469
- id: tmt_qc_report
  label: TMT QC Report
  type:
  - 'null'
  - File
  outputSource:
  - tmt_integrator_qc/tmt_qc_report
  sbg:x: 207.99998474121094
  sbg:y: -156.19845581054688

steps:
- id: tmt_integrator_qc
  label: TMT-Integrator QC
  in:
  - id: tmt_gene_report
    source: tmt_integrator/abundance_by_gene_report
  run: fragpipe-tmt-integrator-and-qc.cwl.steps/tmt_integrator_qc.cwl
  out:
  - id: tmt_qc_report
  sbg:x: 49
  sbg:y: 12
- id: tmt_integrator
  label: tmt_integrator
  in:
  - id: psm_file
    source:
    - psm_file
  - id: database
    source: database
  run: fragpipe-tmt-integrator-and-qc.cwl.steps/tmt_integrator.cwl
  out:
  - id: all_report_files
  - id: abundance_by_gene_report
  sbg:x: -118
  sbg:y: -138

hints:
- class: sbg:AWSInstanceType
  value: r5.xlarge;ebs-gp2;200
sbg:appVersion:
- v1.1
sbg:categories:
- Proteomics
sbg:content_hash: ae0e5b97dd4fa1b912e0df5f4dc491c2e6c808735c5e97296e8d15f920a6d8e8f
sbg:contributors:
- david.roberson
sbg:createdBy: david.roberson
sbg:createdOn: 1618978230
sbg:id: |-
  david.roberson/build-fragpipe-proteomics-pipeline-tutorial/fragpipe-tmt-integrator-and-qc/0
sbg:image_url: |-
  https://cgc.sbgenomics.com/ns/brood/images/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/fragpipe-tmt-integrator-and-qc/0.png
sbg:latestRevision: 0
sbg:links:
- id: https://fragpipe.nesvilab.org/
  label: fragpipe.nesvilab.org
sbg:modifiedBy: david.roberson
sbg:modifiedOn: 1618978230
sbg:original_source: |-
  https://cgc-api.sbgenomics.com/v2/apps/david.roberson/build-fragpipe-proteomics-pipeline-tutorial/fragpipe-tmt-integrator-and-qc/0/raw/
sbg:project: david.roberson/build-fragpipe-proteomics-pipeline-tutorial
sbg:projectName: 'BUILD: FragPipe Proteomics Pipeline Tutorial'
sbg:publisher: sbg
sbg:revision: 0
sbg:revisionNotes: |-
  Uploaded using sbpack v2020.10.05. 
  Source: 
  repo: https://github.com/davidroberson/fragpipe-proteomics-pipeline-tutorial.git
  file: 
  commit: (uncommitted file)
sbg:revisionsInfo:
- sbg:modifiedBy: david.roberson
  sbg:modifiedOn: 1618978230
  sbg:revision: 0
  sbg:revisionNotes: |-
    Uploaded using sbpack v2020.10.05. 
    Source: 
    repo: https://github.com/davidroberson/fragpipe-proteomics-pipeline-tutorial.git
    file: 
    commit: (uncommitted file)
sbg:sbgMaintained: false
sbg:toolAuthor: Felipe da Veiga Leprevost
sbg:toolkit: FragPipe
sbg:toolkitVersion: v15.0
sbg:validationErrors: []
sbg:wrapperAuthor: Felipe da Veiga Leprevost; Dave Roberson
